@@ -55,11 +55,10 @@ class Statbotics:
             if retry < 2:
                 return self._get(url, fields, retry=retry + 1)
             raise UserWarning("Invalid query: " + url)
+
         data = resp.json()
-        try:
-            return data["results"]
-        except KeyError:
-            return data
+        if "results" in data:
+            data = data["results"]
 
         if len(data) == 0:
             raise UserWarning("Invalid inputs, no data recieved for " + url)
